<?php
/**
 * @package            Joomla
 * @subpackage         Event Booking
 * @author             Tuan Pham Ngoc
 * @copyright          Copyright (C) 2010 - 2021 Ossolution Team
 * @license            GNU/GPL, see LICENSE.php
 */

defined('_JEXEC') or die;

use Joomla\Registry\Registry;

class EventbookingHelperOverrideRegistration extends EventbookingHelperRegistration
{
	/**
	 * Method to calculate payment processing fee
	 *
	 * @param   string   $paymentMethod
	 * @param   float    $amount
	 * @param   boolean  $includeFeeAmount
	 *
	 * @return float
	 */
	public static function calculatePaymentProcessingFee($paymentMethod, $amount, $includeFeeAmount = true)
	{
		if ($paymentMethod)
		{
			$method            = EventbookingHelperPayments::loadPaymentMethod($paymentMethod);
			$params            = new Registry($method->params);
			$paymentFeeAmount  = $includeFeeAmount ? (float) $params->get('payment_fee_amount') : 0;
			$paymentFeePercent = (float) $params->get('payment_fee_percent');

			if ($paymentFeeAmount != 0 || $paymentFeePercent != 0)
			{
				return round(($amount + $paymentFeeAmount) / (1 - $paymentFeePercent / 100), 2);
			}
		}

		return 0.00;
	}
}